from fugashi import GenericTagger
import ipadic
import textspan
import tokenizers


class IpadicTagger(GenericTagger):
    """
    fugashi with ipadic
    """
    def __init__(self):
        super().__init__(ipadic.MECAB_ARGS)


class IpadicPreTokenizer(object):
    """
    PreTokenizer with IpadicTagger
    Note that, since this PreTokenizer is not serializable,
    we have to load model and pretokenizer separately.
    """

    @classmethod
    def make(cls):
        """instantiate a PreTokenizer object."""
        return tokenizers.pre_tokenizers.PreTokenizer.custom(cls())

    def __init__(self):

        self.tagger = IpadicTagger()

    def _pre_tokenize(self, _id, ns):

        text = ns.normalized
        tokens = [n.surface for n in self.tagger.parseToNodeList(text)]
        tokens_spans = textspan.get_original_spans(tokens, text)
        return [ns[sp:ep] for sub_spans in tokens_spans for sp, ep in sub_spans]

    def pre_tokenize(self, pretok):

        pretok.split(self._pre_tokenize)



from fugashi import GenericTagger
import ipadic

from .ipadic import IpadicPreTokenizer


def try_load_manbyo_dict_path():
    try:
        import os
        MANBYO_DICT_PATH = os.environ["MANBYO_DICT_PATH"]
        return MANBYO_DICT_PATH
    except Exception as e:
        print(e)


class ManbyoDictTagger(GenericTagger):
    """
    fugashi with ipadic and manbyo dictionaries
    """
    MANBYO_DICT_PATH = try_load_manbyo_dict_path()

    MECAB_ARGS = ' '.join([ipadic.MECAB_ARGS, '-u ' + MANBYO_DICT_PATH])

    def __init__(self):
        super().__init__(self.MECAB_ARGS)


class ManbyoDictPreTokenizer(IpadicPreTokenizer):
    """
    PreTokenizer with CustomTagger
    Note that, since this PreTokenizer is not serializable,
    we have to load model and pretokenizer separately.
    """

    def __init__(self):

        self.tagger = ManbyoDictTagger()



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['japre']

package_data = \
{'': ['*']}

install_requires = \
['flake8>=4.0.1,<5.0.0',
 'fugashi>=1.1.2,<2.0.0',
 'ipadic>=1.0.0,<2.0.0',
 'pytextspan>=0.5.4,<0.6.0',
 'tokenizers>=0.12.1,<0.13.0']

setup_kwargs = {
    'name': 'japre',
    'version': '0.1.3',
    'description': 'Custom pretokenizers for Japanese language models',
    'long_description': '# japanese_pretokenizers (japre)\n\nCustom pretokenizers for Japanese language models\n\n## installation\n\n```\npip install japre\n```\n\n## Usage\n\n### IpadicPreTokenizer\n\n```python\nfrom japre.ipadic import IpadicPreTokenizer\n\nfrom transformers import PreTrainedTokenizerFast\nfrom tokenizers import Tokenizer\n\ntokenizer_object = Tokenizer.from_file("your-awesome-tokenizer.json")\ntokenizer_object.pre_tokenizer = IpadicPreTokenizer.make()\ntokenizer = PreTrainedTokenizerFast(\n    tokenizer_object=tokenizer_object,\n    unk_token=\'[UNK]\',\n    mask_token=\'[MASK]\',\n    cls_token=\'[CLS]\',\n    pad_token=\'[PAD]\',\n    sep_token=\'[SEP]\'\n)\n```\n\n### ManbyoDictPreTokenizer\n\n```\nexport MANBYO_DICT_PATH=/path/to/MANBYO_201907_Dic-utf8.dic\n```\n\n```python\nfrom japre.manbyo import ManbyoDictPreTokenizer\n\nfrom transformers import PreTrainedTokenizerFast\nfrom tokenizers import Tokenizer\n\ntokenizer_object = Tokenizer.from_file("your-awesome-tokenizer.json")\ntokenizer_object.pre_tokenizer = ManbyoDictPreTokenizer.make()\ntokenizer = PreTrainedTokenizerFast(\n    tokenizer_object=tokenizer_object,\n    unk_token=\'[UNK]\',\n    mask_token=\'[MASK]\',\n    cls_token=\'[CLS]\',\n    pad_token=\'[PAD]\',\n    sep_token=\'[SEP]\'\n)\n```',
    'author': 'Kaito Sugimoto',
    'author_email': 'kaito_sugimoto@is.s.u-tokyo.ac.jp',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Alab-NII/japanese_pretokenizers',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
